@@ -44,16 +44,22 @@ static const char rcsid[]="$Id: hci.c,v 1.5 2002/01/27 13:22:57 jab Exp jab $";
 #include<fcntl.h>
 #include<sys/stat.h>
 #include<sys/ioctl.h>
+#include<sys/errno.h>
 
 #include"hci.h"
 
+/* devfs uses a different name, not defined in the kernel includes */
+#define TOSH_DEVFS_DEVICE "/dev/misc/toshiba"
 
 int HciFunction(SMMRegisters *regs)
 {
 	int fd;
 
-	if ((fd=open(TOSH_DEVICE, O_RDWR))<0)
-		return HCI_FAILURE;
+	fd=open(TOSH_DEVFS_DEVICE, O_RDWR);
+	if (fd<0 && errno==ENOENT)
+	   fd=open(TOSH_DEVICE, O_RDWR);
+	if (fd<0)
+	   return HCI_FAILURE;
 
 	if (access(TOSH_PROC, R_OK)) {
 		close(fd);
