@@ -74,9 +74,30 @@ static const char rcsid[]="$Id: sci.c,v 1.14 2001/10/05 13:07:40 jab Exp jab $";
 #include<fcntl.h>
 #include<sys/stat.h>
 #include<sys/ioctl.h>
+#include<sys/errno.h>
 
 #include"sci.h"
 
+/* devfs uses a different name, not defined in the kernel includes */
+#define TOSH_DEVFS_DEVICE "/dev/misc/toshiba"
+
+
+/*
+ * Open the toshiba device; try the devfs name first then fall back
+ * Local function only, not to be exported in order to prevent 
+ * namespace pollution.
+ */
+int OpenDevice()
+{
+	int fd;
+
+	fd=open(TOSH_DEVFS_DEVICE, O_RDWR);
+	if (fd<0 && errno==ENOENT) {
+		fd=open(TOSH_DEVICE, O_RDWR);
+	}
+	
+	return fd;
+}
 
 /*
  * Is this a supported Machine? (ie. is it a Toshiba)
@@ -86,7 +107,7 @@ int SciSupportCheck(int *version)
 	SMMRegisters regs;
 	int fd;
 
-	if ((fd=open(TOSH_DEVICE, O_RDWR))<0)
+	if ((fd=OpenDevice())<0)
 		return SCI_FAILURE;
 
 	if (access(TOSH_PROC, R_OK)) {
@@ -121,7 +142,7 @@ int SciOpenInterface(void)
 	SMMRegisters regs;
 	int fd;
 
-	if ((fd=open(TOSH_DEVICE, O_RDWR ))<0)
+	if ((fd=OpenDevice())<0)
 		return SCI_FAILURE;
 
 	regs.eax = 0xf1f1;
@@ -146,7 +167,7 @@ int SciCloseInterface(void)
 	SMMRegisters regs;
 	int fd;
 
-	if ((fd=open(TOSH_DEVICE, O_RDWR ))<0)
+	if ((fd=OpenDevice())<0)
 		return SCI_FAILURE;
 
 	regs.eax = 0xf2f2;
@@ -170,7 +191,7 @@ int SciGet(SMMRegisters *regs)
 {
 	int fd;
 
-	if ((fd=open(TOSH_DEVICE, O_RDWR ))<0)
+	if ((fd=OpenDevice())<0)
 		return SCI_FAILURE;
 
 	regs->eax = 0xf3f3;
@@ -192,7 +213,7 @@ int SciSet(SMMRegisters *regs)
 {
 	int fd;
 
-	if ((fd=open(TOSH_DEVICE, O_RDWR ))<0)
+	if ((fd=OpenDevice())<0)
 		return SCI_FAILURE;
 
 	regs->eax = 0xf4f4;
@@ -218,7 +239,7 @@ int SciACPower(void)
 	if (access(TOSH_PROC, R_OK))
 		return SCI_FAILURE;
 
-	if ((fd=open(TOSH_DEVICE, O_RDWR))<0)
+	if ((fd=OpenDevice())<0)
 		return SCI_FAILURE;
 
 	regs.eax = 0xfefe;
